/*
 *   Copyright (c) International Business Machines  Corp.2005
 *              
 *   This program is free software;  you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 2 of the License, or
 *   (at your option) any later version.
 *       
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY;  without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
 *   the GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program;  if not, write to the Free Software
 *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 ***************************************************************************
 * File: stress3_test.c
 *
 * Description: This test stresses auditd by making repeated syscalls and
 *              rotating the log files repeatedly.  The number of syscalls
 *              can be increased in the loop to as many as you wish.  The
 *              disk will not fill up because the log files are rotated and
 *              reused.  The intent of this test is not to check for lost
 *              records; see noloss_test.c and the disk handling tests.  
 *
 * Total Tests: 1M passes through loop; can be altered.
 *
 * Test Name: stress3_test
 *
 * Test Assertion & Strategy:
 *
 *              This test is called by stess3_test.sh as ealuser and
 *              successfully creates, chmods, and removes a directory 
 *              in /tmp.  Stress1_test should be run in another window as 
 *              root at the same time as this test; it will result in 
 *              successful syscall audit records. Stress2_test should also 
 *              be run at the same time in another window logged in as 
 *              ealuser, which resultd in error case records.  Start 
 *              stress1_test first; it contains the setup for all tests.
 *      
 *              At the end of the test you should visually verify that the
 *              log files contain records for uid's 0 and 560 with 
 *              "success=yes" and records for uid 500 with "success=no".  
 *              If either of these is missing, the test has failed.
 *
 *              If these tests terminate prematurely, you may need to 
 *              restore the original /etc/auditd.conf file from
 *              /etc/auditd.conf.save. Premature termination caused by a
 *              problem with the system must be considered a failure and
 *              investigated. When the test completes normally, a completion
 *              message will display.
 *
 * Usage:  <for command-line>  stress3_test.sh   (executes stress3_test)
 *
 * History:
 *
 * FLAG   DATE     NAME               DESCRIPTION
 *       4/19/05  krisw@us.ibm.com  Created this test.
 *
 ****************************************************************************/

#include <stdio.h>
#include <stdlib.h>
#include <sys/types.h>
#include <sys/stat.h>
#include <sys/fcntl.h>
#include <asm/unistd.h>
#include <signal.h>

mode_t mode;                    /* mode for directory creation*/
int rc;

int main(int ac, char **av)
{
   int lc;                      /* loop counter */
   char *msg;                   /* message returned from parse_opts */
   char dirname[40] ="/tmp/stress3_dir";

/* Exercise the rules  1,000,000 times. */

     for (lc = 0; lc < 1000000; lc++) {
        printf("THIS IS LOOP %d \n", lc);
        syscall(__NR_mkdir,dirname,mode);
        syscall(__NR_chmod,dirname,mode);
        syscall(__NR_rmdir,dirname);
     }
  
     printf("The stress3_test has completed normally. \n"); 
     return(0);
}

